/****************************************************************************
** Meta object code from reading C++ file 'globalconfig.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../globalconfig.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'globalconfig.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12GlobalConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto GlobalConfig::qt_create_metaobjectdata<qt_meta_tag_ZN12GlobalConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GlobalConfig",
        "VolumeStepChanged",
        "",
        "RaiseMaximumVolumeChanged",
        "AudioFeedbackChanged",
        "VolumeOsdChanged",
        "MicrophoneSensitivityOsdChanged",
        "MuteOsdChanged",
        "PushToTalkOsdChanged",
        "MutedMicrophoneReminderOsdChanged",
        "DefaultOutputDeviceOsdChanged",
        "GlobalMuteSinksChanged",
        "GlobalMuteSinksMutedDevicesChanged",
        "GlobalMuteSourcesChanged",
        "GlobalMuteSourcesMutedDevicesChanged",
        "volumeStep",
        "isVolumeStepImmutable",
        "raiseMaximumVolume",
        "isRaiseMaximumVolumeImmutable",
        "audioFeedback",
        "isAudioFeedbackImmutable",
        "volumeOsd",
        "isVolumeOsdImmutable",
        "microphoneSensitivityOsd",
        "isMicrophoneSensitivityOsdImmutable",
        "muteOsd",
        "isMuteOsdImmutable",
        "pushToTalkOsd",
        "isPushToTalkOsdImmutable",
        "mutedMicrophoneReminderOsd",
        "isMutedMicrophoneReminderOsdImmutable",
        "defaultOutputDeviceOsd",
        "isDefaultOutputDeviceOsdImmutable",
        "globalMuteSinks",
        "isGlobalMuteSinksImmutable",
        "globalMuteSinksMutedDevices",
        "isGlobalMuteSinksMutedDevicesImmutable",
        "globalMuteSources",
        "isGlobalMuteSourcesImmutable",
        "globalMuteSourcesMutedDevices",
        "isGlobalMuteSourcesMutedDevicesImmutable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'VolumeStepChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RaiseMaximumVolumeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AudioFeedbackChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'VolumeOsdChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MicrophoneSensitivityOsdChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MuteOsdChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PushToTalkOsdChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MutedMicrophoneReminderOsdChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DefaultOutputDeviceOsdChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GlobalMuteSinksChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GlobalMuteSinksMutedDevicesChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GlobalMuteSourcesChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GlobalMuteSourcesMutedDevicesChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'volumeStep'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isVolumeStepImmutable'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'raiseMaximumVolume'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isRaiseMaximumVolumeImmutable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'audioFeedback'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isAudioFeedbackImmutable'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'volumeOsd'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isVolumeOsdImmutable'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'microphoneSensitivityOsd'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isMicrophoneSensitivityOsdImmutable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'muteOsd'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isMuteOsdImmutable'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pushToTalkOsd'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isPushToTalkOsdImmutable'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mutedMicrophoneReminderOsd'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isMutedMicrophoneReminderOsdImmutable'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOutputDeviceOsd'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isDefaultOutputDeviceOsdImmutable'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'globalMuteSinks'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isGlobalMuteSinksImmutable'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'globalMuteSinksMutedDevices'
        QtMocHelpers::PropertyData<QStringList>(35, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isGlobalMuteSinksMutedDevicesImmutable'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'globalMuteSources'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isGlobalMuteSourcesImmutable'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'globalMuteSourcesMutedDevices'
        QtMocHelpers::PropertyData<QStringList>(39, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isGlobalMuteSourcesMutedDevicesImmutable'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GlobalConfig, qt_meta_tag_ZN12GlobalConfigE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GlobalConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<GlobalConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12GlobalConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12GlobalConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12GlobalConfigE_t>.metaTypes,
    nullptr
} };

void GlobalConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GlobalConfig *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->VolumeStepChanged(); break;
        case 1: _t->RaiseMaximumVolumeChanged(); break;
        case 2: _t->AudioFeedbackChanged(); break;
        case 3: _t->VolumeOsdChanged(); break;
        case 4: _t->MicrophoneSensitivityOsdChanged(); break;
        case 5: _t->MuteOsdChanged(); break;
        case 6: _t->PushToTalkOsdChanged(); break;
        case 7: _t->MutedMicrophoneReminderOsdChanged(); break;
        case 8: _t->DefaultOutputDeviceOsdChanged(); break;
        case 9: _t->GlobalMuteSinksChanged(); break;
        case 10: _t->GlobalMuteSinksMutedDevicesChanged(); break;
        case 11: _t->GlobalMuteSourcesChanged(); break;
        case 12: _t->GlobalMuteSourcesMutedDevicesChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GlobalConfig::*)()>(_a, &GlobalConfig::VolumeStepChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalConfig::*)()>(_a, &GlobalConfig::RaiseMaximumVolumeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalConfig::*)()>(_a, &GlobalConfig::AudioFeedbackChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalConfig::*)()>(_a, &GlobalConfig::VolumeOsdChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalConfig::*)()>(_a, &GlobalConfig::MicrophoneSensitivityOsdChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalConfig::*)()>(_a, &GlobalConfig::MuteOsdChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalConfig::*)()>(_a, &GlobalConfig::PushToTalkOsdChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalConfig::*)()>(_a, &GlobalConfig::MutedMicrophoneReminderOsdChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalConfig::*)()>(_a, &GlobalConfig::DefaultOutputDeviceOsdChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalConfig::*)()>(_a, &GlobalConfig::GlobalMuteSinksChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalConfig::*)()>(_a, &GlobalConfig::GlobalMuteSinksMutedDevicesChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalConfig::*)()>(_a, &GlobalConfig::GlobalMuteSourcesChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalConfig::*)()>(_a, &GlobalConfig::GlobalMuteSourcesMutedDevicesChanged, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->volumeStep(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isVolumeStepImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->raiseMaximumVolume(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isRaiseMaximumVolumeImmutable(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->audioFeedback(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isAudioFeedbackImmutable(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->volumeOsd(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isVolumeOsdImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->microphoneSensitivityOsd(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isMicrophoneSensitivityOsdImmutable(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->muteOsd(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isMuteOsdImmutable(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->pushToTalkOsd(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isPushToTalkOsdImmutable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->mutedMicrophoneReminderOsd(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isMutedMicrophoneReminderOsdImmutable(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->defaultOutputDeviceOsd(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->isDefaultOutputDeviceOsdImmutable(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->globalMuteSinks(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isGlobalMuteSinksImmutable(); break;
        case 20: *reinterpret_cast<QStringList*>(_v) = _t->globalMuteSinksMutedDevices(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->isGlobalMuteSinksMutedDevicesImmutable(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->globalMuteSources(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->isGlobalMuteSourcesImmutable(); break;
        case 24: *reinterpret_cast<QStringList*>(_v) = _t->globalMuteSourcesMutedDevices(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isGlobalMuteSourcesMutedDevicesImmutable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setVolumeStep(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setRaiseMaximumVolume(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setAudioFeedback(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setVolumeOsd(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setMicrophoneSensitivityOsd(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setMuteOsd(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setPushToTalkOsd(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setMutedMicrophoneReminderOsd(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setDefaultOutputDeviceOsd(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setGlobalMuteSinks(*reinterpret_cast<bool*>(_v)); break;
        case 20: _t->setGlobalMuteSinksMutedDevices(*reinterpret_cast<QStringList*>(_v)); break;
        case 22: _t->setGlobalMuteSources(*reinterpret_cast<bool*>(_v)); break;
        case 24: _t->setGlobalMuteSourcesMutedDevices(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *GlobalConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GlobalConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12GlobalConfigE_t>.strings))
        return static_cast<void*>(this);
    return GlobalConfigSkeleton::qt_metacast(_clname);
}

int GlobalConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GlobalConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void GlobalConfig::VolumeStepChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void GlobalConfig::RaiseMaximumVolumeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void GlobalConfig::AudioFeedbackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void GlobalConfig::VolumeOsdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void GlobalConfig::MicrophoneSensitivityOsdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void GlobalConfig::MuteOsdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void GlobalConfig::PushToTalkOsdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void GlobalConfig::MutedMicrophoneReminderOsdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void GlobalConfig::DefaultOutputDeviceOsdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void GlobalConfig::GlobalMuteSinksChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void GlobalConfig::GlobalMuteSinksMutedDevicesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void GlobalConfig::GlobalMuteSourcesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void GlobalConfig::GlobalMuteSourcesMutedDevicesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
