/****************************************************************************
** Meta object code from reading C++ file 'osdservice.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "osdservice.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'osdservice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19OsdServiceInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OsdServiceInterface::qt_create_metaobjectdata<qt_meta_tag_ZN19OsdServiceInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OsdServiceInterface",
        "osdProgress",
        "",
        "icon",
        "percent",
        "additionalText",
        "osdText",
        "text",
        "brightnessChanged",
        "QDBusPendingReply<>",
        "hide",
        "kbdLayoutChanged",
        "layoutName",
        "keyboardBrightnessChanged",
        "mediaPlayerVolumeChanged",
        "playerName",
        "playerIconName",
        "microphoneVolumeChanged",
        "showText",
        "virtualDesktopChanged",
        "currentVirtualDesktopName",
        "volumeChanged",
        "maximumPercent"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'osdProgress'
        QtMocHelpers::SignalData<void(const QString &, int, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'osdText'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'brightnessChanged'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(8, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'hide'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(10, 2, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'kbdLayoutChanged'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(11, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'keyboardBrightnessChanged'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(13, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'mediaPlayerVolumeChanged'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, const QString &, const QString &)>(14, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'microphoneVolumeChanged'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(17, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'showText'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(18, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'virtualDesktopChanged'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(19, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'volumeChanged'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, int)>(21, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::Int, 4 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'volumeChanged'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(21, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::Int, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OsdServiceInterface, qt_meta_tag_ZN19OsdServiceInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OsdServiceInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19OsdServiceInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19OsdServiceInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19OsdServiceInterfaceE_t>.metaTypes,
    nullptr
} };

void OsdServiceInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OsdServiceInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->osdProgress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 1: _t->osdText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: { QDBusPendingReply<> _r = _t->brightnessChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<> _r = _t->hide();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->kbdLayoutChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<> _r = _t->keyboardBrightnessChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<> _r = _t->mediaPlayerVolumeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->microphoneVolumeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->showText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->virtualDesktopChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->volumeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->volumeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OsdServiceInterface::*)(const QString & , int , const QString & )>(_a, &OsdServiceInterface::osdProgress, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OsdServiceInterface::*)(const QString & , const QString & )>(_a, &OsdServiceInterface::osdText, 1))
            return;
    }
}

const QMetaObject *OsdServiceInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OsdServiceInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19OsdServiceInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OsdServiceInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void OsdServiceInterface::osdProgress(const QString & _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void OsdServiceInterface::osdText(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
