/****************************************************************************
** Meta object code from reading C++ file 'microphonetest.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-pa-6.6.90/src/microphonetest.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'microphonetest.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14MicrophoneTestE_t {};
} // unnamed namespace

template <> constexpr inline auto MicrophoneTest::qt_create_metaobjectdata<qt_meta_tag_ZN14MicrophoneTestE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MicrophoneTest",
        "volumeLevelChanged",
        "",
        "sourceChanged",
        "hasRecordingChanged",
        "showErrorMessage",
        "message",
        "recordingFinished",
        "playbackFinished",
        "playingChanged",
        "recordingChanged",
        "setSource",
        "PulseAudioQt::Source*",
        "source",
        "startRecording",
        "stopRecording",
        "stopPlaying",
        "playRecording",
        "clearRecording",
        "cleanupStreams",
        "volumeLevel",
        "hasRecording",
        "playing",
        "recording"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'volumeLevelChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasRecordingChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showErrorMessage'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'recordingFinished'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playbackFinished'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playingChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'recordingChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setSource'
        QtMocHelpers::SlotData<void(PulseAudioQt::Source *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'startRecording'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopRecording'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopPlaying'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'playRecording'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearRecording'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cleanupStreams'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'volumeLevel'
        QtMocHelpers::PropertyData<double>(20, QMetaType::Double, QMC::DefaultPropertyFlags, 0),
        // property 'source'
        QtMocHelpers::PropertyData<PulseAudioQt::Source*>(13, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'hasRecording'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'playing'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'recording'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MicrophoneTest, qt_meta_tag_ZN14MicrophoneTestE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MicrophoneTest::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MicrophoneTestE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MicrophoneTestE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14MicrophoneTestE_t>.metaTypes,
    nullptr
} };

void MicrophoneTest::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MicrophoneTest *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->volumeLevelChanged(); break;
        case 1: _t->sourceChanged(); break;
        case 2: _t->hasRecordingChanged(); break;
        case 3: _t->showErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->recordingFinished(); break;
        case 5: _t->playbackFinished(); break;
        case 6: _t->playingChanged(); break;
        case 7: _t->recordingChanged(); break;
        case 8: _t->setSource((*reinterpret_cast<std::add_pointer_t<PulseAudioQt::Source*>>(_a[1]))); break;
        case 9: _t->startRecording(); break;
        case 10: _t->stopRecording(); break;
        case 11: _t->stopPlaying(); break;
        case 12: _t->playRecording(); break;
        case 13: _t->clearRecording(); break;
        case 14: _t->cleanupStreams(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PulseAudioQt::Source* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MicrophoneTest::*)()>(_a, &MicrophoneTest::volumeLevelChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MicrophoneTest::*)()>(_a, &MicrophoneTest::sourceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MicrophoneTest::*)()>(_a, &MicrophoneTest::hasRecordingChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MicrophoneTest::*)(const QString & )>(_a, &MicrophoneTest::showErrorMessage, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MicrophoneTest::*)()>(_a, &MicrophoneTest::recordingFinished, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MicrophoneTest::*)()>(_a, &MicrophoneTest::playbackFinished, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MicrophoneTest::*)()>(_a, &MicrophoneTest::playingChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MicrophoneTest::*)()>(_a, &MicrophoneTest::recordingChanged, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PulseAudioQt::Source* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<double*>(_v) = _t->volumeLevel(); break;
        case 1: *reinterpret_cast<PulseAudioQt::Source**>(_v) = _t->source(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->hasRecording(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->playing(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->recording(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setSource(*reinterpret_cast<PulseAudioQt::Source**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MicrophoneTest::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MicrophoneTest::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MicrophoneTestE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MicrophoneTest::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void MicrophoneTest::volumeLevelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MicrophoneTest::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MicrophoneTest::hasRecordingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MicrophoneTest::showErrorMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void MicrophoneTest::recordingFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MicrophoneTest::playbackFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void MicrophoneTest::playingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void MicrophoneTest::recordingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
