/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was osdService.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef OSDSERVICE_H
#define OSDSERVICE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.osdService
 */
class OsdServiceInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.osdService"; }

public:
    OsdServiceInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OsdServiceInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> brightnessChanged(int percent)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(percent);
        return asyncCallWithArgumentList(QStringLiteral("brightnessChanged"), argumentList);
    }

    inline QDBusPendingReply<> hide()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("hide"), argumentList);
    }

    inline QDBusPendingReply<> kbdLayoutChanged(const QString &layoutName)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(layoutName);
        return asyncCallWithArgumentList(QStringLiteral("kbdLayoutChanged"), argumentList);
    }

    inline QDBusPendingReply<> keyboardBrightnessChanged(int percent)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(percent);
        return asyncCallWithArgumentList(QStringLiteral("keyboardBrightnessChanged"), argumentList);
    }

    inline QDBusPendingReply<> mediaPlayerVolumeChanged(int percent, const QString &playerName, const QString &playerIconName)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(percent) << QVariant::fromValue(playerName) << QVariant::fromValue(playerIconName);
        return asyncCallWithArgumentList(QStringLiteral("mediaPlayerVolumeChanged"), argumentList);
    }

    inline QDBusPendingReply<> microphoneVolumeChanged(int percent)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(percent);
        return asyncCallWithArgumentList(QStringLiteral("microphoneVolumeChanged"), argumentList);
    }

    inline QDBusPendingReply<> showText(const QString &icon, const QString &text)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(icon) << QVariant::fromValue(text);
        return asyncCallWithArgumentList(QStringLiteral("showText"), argumentList);
    }

    inline QDBusPendingReply<> virtualDesktopChanged(const QString &currentVirtualDesktopName)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(currentVirtualDesktopName);
        return asyncCallWithArgumentList(QStringLiteral("virtualDesktopChanged"), argumentList);
    }

    inline QDBusPendingReply<> volumeChanged(int percent, int maximumPercent)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(percent) << QVariant::fromValue(maximumPercent);
        return asyncCallWithArgumentList(QStringLiteral("volumeChanged"), argumentList);
    }

    inline QDBusPendingReply<> volumeChanged(int percent)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(percent);
        return asyncCallWithArgumentList(QStringLiteral("volumeChanged"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void osdProgress(const QString &icon, int percent, const QString &additionalText);
    void osdText(const QString &icon, const QString &text);
};

namespace org {
  namespace kde {
    using osdService = ::OsdServiceInterface;
  }
}

#endif
