// This file is generated by kconfig_compiler_kf6 from globalconfig.kcfg.
// All changes you do to this file will be lost.

#include "globalconfig.h"

GlobalConfig::GlobalConfig( QObject *parent )
  : GlobalConfigSkeleton( QStringLiteral( "plasmaparc" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&GlobalConfig::itemChanged);

  setCurrentGroup( QStringLiteral( "General" ) );

  KConfigCompilerSignallingItem  *itemVolumeStep;
  GlobalConfigSkeleton::ItemInt  *innerItemVolumeStep;
  innerItemVolumeStep = new GlobalConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "VolumeStep" ), mVolumeStep, 5 );
  itemVolumeStep = new KConfigCompilerSignallingItem(innerItemVolumeStep, this, notifyFunction, signalVolumeStepChanged);
  itemVolumeStep->setWriteFlags(KConfigBase::Notify);
  addItem( itemVolumeStep, QStringLiteral( "VolumeStep" ) );
  KConfigCompilerSignallingItem  *itemRaiseMaximumVolume;
  GlobalConfigSkeleton::ItemBool  *innerItemRaiseMaximumVolume;
  innerItemRaiseMaximumVolume = new GlobalConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "RaiseMaximumVolume" ), mRaiseMaximumVolume, false );
  itemRaiseMaximumVolume = new KConfigCompilerSignallingItem(innerItemRaiseMaximumVolume, this, notifyFunction, signalRaiseMaximumVolumeChanged);
  itemRaiseMaximumVolume->setWriteFlags(KConfigBase::Notify);
  addItem( itemRaiseMaximumVolume, QStringLiteral( "RaiseMaximumVolume" ) );
  KConfigCompilerSignallingItem  *itemAudioFeedback;
  GlobalConfigSkeleton::ItemBool  *innerItemAudioFeedback;
  innerItemAudioFeedback = new GlobalConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AudioFeedback" ), mAudioFeedback, true );
  itemAudioFeedback = new KConfigCompilerSignallingItem(innerItemAudioFeedback, this, notifyFunction, signalAudioFeedbackChanged);
  itemAudioFeedback->setWriteFlags(KConfigBase::Notify);
  addItem( itemAudioFeedback, QStringLiteral( "AudioFeedback" ) );
  KConfigCompilerSignallingItem  *itemVolumeOsd;
  GlobalConfigSkeleton::ItemBool  *innerItemVolumeOsd;
  innerItemVolumeOsd = new GlobalConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "VolumeOsd" ), mVolumeOsd, true );
  itemVolumeOsd = new KConfigCompilerSignallingItem(innerItemVolumeOsd, this, notifyFunction, signalVolumeOsdChanged);
  itemVolumeOsd->setWriteFlags(KConfigBase::Notify);
  addItem( itemVolumeOsd, QStringLiteral( "VolumeOsd" ) );
  KConfigCompilerSignallingItem  *itemMicrophoneSensitivityOsd;
  GlobalConfigSkeleton::ItemBool  *innerItemMicrophoneSensitivityOsd;
  innerItemMicrophoneSensitivityOsd = new GlobalConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "MicrophoneSensitivityOsd" ), mMicrophoneSensitivityOsd, true );
  itemMicrophoneSensitivityOsd = new KConfigCompilerSignallingItem(innerItemMicrophoneSensitivityOsd, this, notifyFunction, signalMicrophoneSensitivityOsdChanged);
  itemMicrophoneSensitivityOsd->setWriteFlags(KConfigBase::Notify);
  addItem( itemMicrophoneSensitivityOsd, QStringLiteral( "MicrophoneSensitivityOsd" ) );
  KConfigCompilerSignallingItem  *itemMuteOsd;
  GlobalConfigSkeleton::ItemBool  *innerItemMuteOsd;
  innerItemMuteOsd = new GlobalConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "MuteOsd" ), mMuteOsd, true );
  itemMuteOsd = new KConfigCompilerSignallingItem(innerItemMuteOsd, this, notifyFunction, signalMuteOsdChanged);
  itemMuteOsd->setWriteFlags(KConfigBase::Notify);
  addItem( itemMuteOsd, QStringLiteral( "MuteOsd" ) );
  KConfigCompilerSignallingItem  *itemPushToTalkOsd;
  GlobalConfigSkeleton::ItemBool  *innerItemPushToTalkOsd;
  innerItemPushToTalkOsd = new GlobalConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "PushToTalkOsd" ), mPushToTalkOsd, true );
  itemPushToTalkOsd = new KConfigCompilerSignallingItem(innerItemPushToTalkOsd, this, notifyFunction, signalPushToTalkOsdChanged);
  itemPushToTalkOsd->setWriteFlags(KConfigBase::Notify);
  addItem( itemPushToTalkOsd, QStringLiteral( "PushToTalkOsd" ) );
  KConfigCompilerSignallingItem  *itemMutedMicrophoneReminderOsd;
  GlobalConfigSkeleton::ItemBool  *innerItemMutedMicrophoneReminderOsd;
  innerItemMutedMicrophoneReminderOsd = new GlobalConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "MutedMicrophoneReminderOsd" ), mMutedMicrophoneReminderOsd, true );
  itemMutedMicrophoneReminderOsd = new KConfigCompilerSignallingItem(innerItemMutedMicrophoneReminderOsd, this, notifyFunction, signalMutedMicrophoneReminderOsdChanged);
  itemMutedMicrophoneReminderOsd->setWriteFlags(KConfigBase::Notify);
  addItem( itemMutedMicrophoneReminderOsd, QStringLiteral( "MutedMicrophoneReminderOsd" ) );
  KConfigCompilerSignallingItem  *itemDefaultOutputDeviceOsd;
  GlobalConfigSkeleton::ItemBool  *innerItemDefaultOutputDeviceOsd;
  innerItemDefaultOutputDeviceOsd = new GlobalConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DefaultOutputDeviceOsd" ), mDefaultOutputDeviceOsd, true );
  itemDefaultOutputDeviceOsd = new KConfigCompilerSignallingItem(innerItemDefaultOutputDeviceOsd, this, notifyFunction, signalDefaultOutputDeviceOsdChanged);
  itemDefaultOutputDeviceOsd->setWriteFlags(KConfigBase::Notify);
  addItem( itemDefaultOutputDeviceOsd, QStringLiteral( "DefaultOutputDeviceOsd" ) );
  KConfigCompilerSignallingItem  *itemGlobalMuteSinks;
  GlobalConfigSkeleton::ItemBool  *innerItemGlobalMuteSinks;
  innerItemGlobalMuteSinks = new GlobalConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "GlobalMuteSinks" ), mGlobalMuteSinks, false );
  itemGlobalMuteSinks = new KConfigCompilerSignallingItem(innerItemGlobalMuteSinks, this, notifyFunction, signalGlobalMuteSinksChanged);
  itemGlobalMuteSinks->setWriteFlags(KConfigBase::Notify);
  addItem( itemGlobalMuteSinks, QStringLiteral( "GlobalMuteSinks" ) );
  KConfigCompilerSignallingItem  *itemGlobalMuteSinksMutedDevices;
  GlobalConfigSkeleton::ItemStringList  *innerItemGlobalMuteSinksMutedDevices;
  innerItemGlobalMuteSinksMutedDevices = new GlobalConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "GlobalMuteSinksMutedDevices" ), mGlobalMuteSinksMutedDevices );
  itemGlobalMuteSinksMutedDevices = new KConfigCompilerSignallingItem(innerItemGlobalMuteSinksMutedDevices, this, notifyFunction, signalGlobalMuteSinksMutedDevicesChanged);
  itemGlobalMuteSinksMutedDevices->setWriteFlags(KConfigBase::Notify);
  addItem( itemGlobalMuteSinksMutedDevices, QStringLiteral( "GlobalMuteSinksMutedDevices" ) );
  KConfigCompilerSignallingItem  *itemGlobalMuteSources;
  GlobalConfigSkeleton::ItemBool  *innerItemGlobalMuteSources;
  innerItemGlobalMuteSources = new GlobalConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "GlobalMuteSources" ), mGlobalMuteSources, false );
  itemGlobalMuteSources = new KConfigCompilerSignallingItem(innerItemGlobalMuteSources, this, notifyFunction, signalGlobalMuteSourcesChanged);
  itemGlobalMuteSources->setWriteFlags(KConfigBase::Notify);
  addItem( itemGlobalMuteSources, QStringLiteral( "GlobalMuteSources" ) );
  KConfigCompilerSignallingItem  *itemGlobalMuteSourcesMutedDevices;
  GlobalConfigSkeleton::ItemStringList  *innerItemGlobalMuteSourcesMutedDevices;
  innerItemGlobalMuteSourcesMutedDevices = new GlobalConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "GlobalMuteSourcesMutedDevices" ), mGlobalMuteSourcesMutedDevices );
  itemGlobalMuteSourcesMutedDevices = new KConfigCompilerSignallingItem(innerItemGlobalMuteSourcesMutedDevices, this, notifyFunction, signalGlobalMuteSourcesMutedDevicesChanged);
  itemGlobalMuteSourcesMutedDevices->setWriteFlags(KConfigBase::Notify);
  addItem( itemGlobalMuteSourcesMutedDevices, QStringLiteral( "GlobalMuteSourcesMutedDevices" ) );
}

GlobalConfig::~GlobalConfig()
{
}


void GlobalConfig::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalVolumeStepChanged:
    Q_EMIT VolumeStepChanged();
    break;
  case signalRaiseMaximumVolumeChanged:
    Q_EMIT RaiseMaximumVolumeChanged();
    break;
  case signalAudioFeedbackChanged:
    Q_EMIT AudioFeedbackChanged();
    break;
  case signalVolumeOsdChanged:
    Q_EMIT VolumeOsdChanged();
    break;
  case signalMicrophoneSensitivityOsdChanged:
    Q_EMIT MicrophoneSensitivityOsdChanged();
    break;
  case signalMuteOsdChanged:
    Q_EMIT MuteOsdChanged();
    break;
  case signalPushToTalkOsdChanged:
    Q_EMIT PushToTalkOsdChanged();
    break;
  case signalMutedMicrophoneReminderOsdChanged:
    Q_EMIT MutedMicrophoneReminderOsdChanged();
    break;
  case signalDefaultOutputDeviceOsdChanged:
    Q_EMIT DefaultOutputDeviceOsdChanged();
    break;
  case signalGlobalMuteSinksChanged:
    Q_EMIT GlobalMuteSinksChanged();
    break;
  case signalGlobalMuteSinksMutedDevicesChanged:
    Q_EMIT GlobalMuteSinksMutedDevicesChanged();
    break;
  case signalGlobalMuteSourcesChanged:
    Q_EMIT GlobalMuteSourcesChanged();
    break;
  case signalGlobalMuteSourcesMutedDevicesChanged:
    Q_EMIT GlobalMuteSourcesMutedDevicesChanged();
    break;
  }
}
