/****************************************************************************
** Meta object code from reading C++ file 'listitemmenu.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-pa-6.6.90/src/qml/listitemmenu.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'listitemmenu.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ListItemMenuE_t {};
} // unnamed namespace

template <> constexpr inline auto ListItemMenu::qt_create_metaobjectdata<qt_meta_tag_ZN12ListItemMenuE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ListItemMenu",
        "itemTypeChanged",
        "",
        "pulseObjectChanged",
        "sourceModelChanged",
        "cardModelChanged",
        "visibleChanged",
        "hasContentChanged",
        "visualParentChanged",
        "open",
        "x",
        "y",
        "openRelative",
        "itemType",
        "ItemType",
        "pulseObject",
        "PulseAudioQt::PulseObject*",
        "sourceModel",
        "QAbstractItemModel*",
        "cardModel",
        "PulseAudioQt::CardModel*",
        "visible",
        "hasContent",
        "visualParent",
        "QQuickItem*",
        "None",
        "Sink",
        "SinkInput",
        "Source",
        "SourceOutput"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'itemTypeChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pulseObjectChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceModelChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cardModelChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visibleChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasContentChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visualParentChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'open'
        QtMocHelpers::MethodData<void(int, int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Method 'openRelative'
        QtMocHelpers::MethodData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'itemType'
        QtMocHelpers::PropertyData<enum ItemType>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'pulseObject'
        QtMocHelpers::PropertyData<PulseAudioQt::PulseObject*>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'sourceModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'cardModel'
        QtMocHelpers::PropertyData<PulseAudioQt::CardModel*>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'visible'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'hasContent'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'visualParent'
        QtMocHelpers::PropertyData<QQuickItem*>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ItemType'
        QtMocHelpers::EnumData<enum ItemType>(14, 14, QMC::EnumFlags{}).add({
            {   25, ItemType::None },
            {   26, ItemType::Sink },
            {   27, ItemType::SinkInput },
            {   28, ItemType::Source },
            {   29, ItemType::SourceOutput },
        }),
    };
    return QtMocHelpers::metaObjectData<ListItemMenu, qt_meta_tag_ZN12ListItemMenuE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ListItemMenu::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ListItemMenuE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ListItemMenuE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ListItemMenuE_t>.metaTypes,
    nullptr
} };

void ListItemMenu::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ListItemMenu *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->itemTypeChanged(); break;
        case 1: _t->pulseObjectChanged(); break;
        case 2: _t->sourceModelChanged(); break;
        case 3: _t->cardModelChanged(); break;
        case 4: _t->visibleChanged(); break;
        case 5: _t->hasContentChanged(); break;
        case 6: _t->visualParentChanged(); break;
        case 7: _t->open((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 8: _t->openRelative(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ListItemMenu::*)()>(_a, &ListItemMenu::itemTypeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ListItemMenu::*)()>(_a, &ListItemMenu::pulseObjectChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ListItemMenu::*)()>(_a, &ListItemMenu::sourceModelChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ListItemMenu::*)()>(_a, &ListItemMenu::cardModelChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ListItemMenu::*)()>(_a, &ListItemMenu::visibleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ListItemMenu::*)()>(_a, &ListItemMenu::hasContentChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ListItemMenu::*)()>(_a, &ListItemMenu::visualParentChanged, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PulseAudioQt::CardModel* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PulseAudioQt::PulseObject* >(); break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum ItemType*>(_v) = _t->itemType(); break;
        case 1: *reinterpret_cast<PulseAudioQt::PulseObject**>(_v) = _t->pulseObject(); break;
        case 2: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->sourceModel(); break;
        case 3: *reinterpret_cast<PulseAudioQt::CardModel**>(_v) = _t->cardModel(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isVisible(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->hasContent(); break;
        case 6: *reinterpret_cast<QQuickItem**>(_v) = _t->visualParent(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setItemType(*reinterpret_cast<enum ItemType*>(_v)); break;
        case 1: _t->setPulseObject(*reinterpret_cast<PulseAudioQt::PulseObject**>(_v)); break;
        case 2: _t->setSourceModel(*reinterpret_cast<QAbstractItemModel**>(_v)); break;
        case 3: _t->setCardModel(*reinterpret_cast<PulseAudioQt::CardModel**>(_v)); break;
        case 6: _t->setVisualParent(*reinterpret_cast<QQuickItem**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ListItemMenu::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ListItemMenu::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ListItemMenuE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int ListItemMenu::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void ListItemMenu::itemTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ListItemMenu::pulseObjectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ListItemMenu::sourceModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ListItemMenu::cardModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ListItemMenu::visibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ListItemMenu::hasContentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ListItemMenu::visualParentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
