/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // main.xml
  0x0,0x0,0x2,0x8,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x27,0x6,0xf5,0xf,0x0,0x16,0x9c,0x53,0x1f,0x30,0x73,0x1e,
  0x6f,0x48,0x2c,0x28,0x22,0x5,0xb6,0xec,0xb4,0x17,0xb4,0xeb,0x9b,0xc3,0xbf,0x97,
  0x95,0xf5,0x6f,0x2a,0x73,0x79,0xa9,0xa0,0xa1,0x4c,0x94,0xa,0x51,0x0,0x49,0x0,
  0x48,0x0,0x6e,0x4e,0xac,0x2,0x5a,0x77,0x12,0xe,0x3a,0x73,0xcc,0x59,0x26,0x94,
  0xcd,0x54,0x20,0x10,0xc,0x87,0xf,0xb4,0x20,0x5,0x47,0xd3,0x64,0xad,0xda,0x96,
  0xec,0xb7,0xd3,0xab,0x53,0x72,0xab,0x23,0x7d,0x3e,0x9f,0x69,0x52,0xd0,0x7f,0xac,
  0x2d,0xac,0xe4,0x77,0xb9,0xe,0x15,0x55,0x8c,0x96,0x18,0x40,0x2e,0x98,0xb6,0x78,
  0x12,0x5a,0xd3,0x49,0xe7,0x46,0x90,0xa,0x6d,0x21,0x27,0xb4,0xd5,0x3d,0x1c,0x33,
  0x10,0x83,0xa,0x54,0xc0,0x66,0xed,0xf5,0x2d,0xb,0xac,0x3b,0xe8,0x71,0xb,0xc0,
  0x9c,0x7e,0x96,0x9f,0x89,0x59,0xe,0x45,0x47,0x15,0x9d,0xd3,0xf1,0x49,0x58,0xdf,
  0xd2,0x16,0x4e,0x43,0xcf,0x8d,0xd3,0x97,0x97,0x5e,0xeb,0x75,0xa1,0xfa,0xd2,0xa9,
  0xaa,0xc5,0xae,0x2e,0x3d,0x42,0xef,0xac,0x2f,0xaa,0xa6,0xd6,0x16,0x9e,0xb5,0x64,
  0x8f,0xf0,0x62,0x8e,0x2a,0x6e,0x96,0x5,0x49,0x72,0xc2,0xef,0xb3,0x3a,0xe8,0xe0,
  0xf7,0x5b,0xfe,0x9b,0x59,0x7f,0xb2,0x31,0xc7,0xec,0xd8,0xb3,0x74,0xec,0xc3,0xf4,
  0xd2,0x49,0xb9,0x79,0x3e,0x57,0xc7,0xde,0x31,0x8d,0x65,0x2b,0xb7,0x7e,0xc7,0x35,
  0xc7,0x72,0x87,0x20,0x5e,0x4a,0xa8,0xbf,0xc5,0xe3,0x36,0xf6,0xd5,0xe2,0x9c,0xd,
  0xcf,0x6e,0x9c,0x99,0xec,0x66,0x10,0xd4,0x14,0xb7,0xb0,0xeb,0x34,0x51,0xd5,0xc7,
  0xdb,0x97,0x5b,0x53,0x51,0xf5,0x2e,0xd7,0x99,0xa8,0x28,0xaa,0x26,0xea,0xba,0x79,
  0xd9,0x19,0xb9,0xfa,0x5f,0xcd,0xd2,0xe9,0x74,0xec,0x99,0xba,0x77,0x24,0xa4,0x96,
  0x7f,0xd7,0x7,0x33,0xfb,0x88,0x7d,0xbf,0xc2,0xcc,0x5f,0x4a,0x6c,0xce,0x8c,0x2f,
  0xf0,0x6e,0xad,0x76,0x8c,0x9b,0x25,0xe4,0x27,0xe1,0x7b,0x37,0x52,0x96,0x9e,0xe4,
  0x0,0x66,0x76,0xfc,0xa5,0x7f,0xa7,0x9c,0x18,0xd,0x43,0x20,0x10,0x10,0x42,0x8c,
  0x93,0xb2,0xe,0xf1,0x25,0x20,0x99,0x18,0xc3,0x1a,0x15,0x81,0xea,0xa0,0x98,0x9d,
  0x71,0xca,0x96,0x23,0xaf,0x50,0xce,0xb0,0x88,0x51,0x97,0x70,0xa3,0x60,0xe9,0x66,
  0x51,0x99,0x38,0x85,0x32,0x36,0x74,0x8d,0xb5,0xc9,0x5,0x3e,0x3b,0x59,0xd4,0x7a,
  0x1,0x55,0x5b,0x23,0x37,0x9b,0xb8,0x32,0x43,0xc2,0xc,0xd4,0xc1,0x35,0x48,0x83,
  0x34,0xe3,0x44,0x82,0x53,0x33,0x97,0x64,0xc2,0xe7,0x6e,0x7b,0x9e,0x85,0xab,0xdf,
  0xa8,0x75,0x34,0x5c,0x88,0xc,0x75,0xc4,0xb0,0xbd,0xcb,0xa6,0xac,0xbe,0x98,0x70,
  0xe8,0x8d,0xcf,0x27,0xd4,0x6b,0x19,0xe5,0x6a,0x7c,0x85,0x81,0x19,0x50,0x19,0xb3,
  0x33,0x7f,0x5c,0x21,0xb8,0x6f,0x39,0x16,0x77,0x80,0x17,0x6d,0x78,0xe,0xae,0x27,
  0xe4,0x55,0xbe,0x9a,0xd5,0x36,0x6b,0x4d,0x85,0xf0,0xf0,0x83,0x64,0x0,0x0,0xb,
  0xf7,0x4,0xf9,0x17,0xbe,0x20,0x96,0xee,0xc2,0xdb,0xa3,0x3b,0xf,0x70,0xa3,0x92,
  0x65,0x61,0xae,0xa4,0xe,0x78,0x7a,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // plasma
  0x0,0x6,
  0x7,0x72,0x8a,0x31,
  0x0,0x70,
  0x0,0x6c,0x0,0x61,0x0,0x73,0x0,0x6d,0x0,0x61,
    // applet
  0x0,0x6,
  0x6,0x87,0x72,0xc4,
  0x0,0x61,
  0x0,0x70,0x0,0x70,0x0,0x6c,0x0,0x65,0x0,0x74,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // kde
  0x0,0x3,
  0x0,0x0,0x71,0xa5,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,
    // volume
  0x0,0x6,
  0x7,0xd6,0x3c,0x35,
  0x0,0x76,
  0x0,0x6f,0x0,0x6c,0x0,0x75,0x0,0x6d,0x0,0x65,
    // main.xml
  0x0,0x8,
  0x8,0x1,0x51,0x5c,
  0x0,0x6d,
  0x0,0x61,0x0,0x69,0x0,0x6e,0x0,0x2e,0x0,0x78,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9e,0x27,0xc6,0x7c,0xa0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9e,0x27,0xc6,0x7c,0xa0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9e,0x27,0xc6,0x7c,0xa0,
  // :/qt/qml/plasma
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9e,0x27,0xc6,0x7c,0xa0,
  // :/qt/qml/plasma/applet
  0x0,0x0,0x0,0x28,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9e,0x27,0xc6,0x7c,0xa0,
  // :/qt/qml/plasma/applet/org
  0x0,0x0,0x0,0x3a,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0x9e,0x27,0xc6,0x7c,0xa0,
  // :/qt/qml/plasma/applet/org/kde
  0x0,0x0,0x0,0x46,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x7,
0x0,0x0,0x1,0x9e,0x27,0xc6,0x7c,0xa0,
  // :/qt/qml/plasma/applet/org/kde/plasma
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x8,
0x0,0x0,0x1,0x9e,0x27,0xc6,0x7c,0xa0,
  // :/qt/qml/plasma/applet/org/kde/plasma/volume
  0x0,0x0,0x0,0x52,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x9,
0x0,0x0,0x1,0x9e,0x27,0xc6,0x7c,0xa0,
  // :/qt/qml/plasma/applet/org/kde/plasma/volume/main.xml
  0x0,0x0,0x0,0x64,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9e,0x27,0xc6,0x7c,0xa0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_org_kde_plasma_volume_raw_res_1)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_org_kde_plasma_volume_raw_res_1)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_org_kde_plasma_volume_raw_res_1)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_org_kde_plasma_volume_raw_res_1)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_org_kde_plasma_volume_raw_res_1)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_org_kde_plasma_volume_raw_res_1)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
